=======================
gpm_precipitation_tools
=======================


.. image:: https://img.shields.io/pypi/v/gpm_precipitation_tools.svg
        :target: https://pypi.python.org/pypi/gpm_precipitation_tools

.. image:: https://img.shields.io/travis/MarinaRuizSO/gpm_precipitation_tools.svg
        :target: https://travis-ci.com/MarinaRuizSO/gpm_precipitation_tools

.. image:: https://readthedocs.org/projects/gpm-precipitation-tools/badge/?version=latest
        :target: https://gpm-precipitation-tools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Package for downloading and analysing NASA Global Precipitation Measurement mission data.


* Free software: MIT license
* Documentation: https://gpm-precipitation-tools.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
